@@ -24,14 +24,14 @@ class Users(object):
 		#
 	def get(self, 
 		# define one of the following parameters.
-		username=None,
+		uid=None,
 		email=None,
 		phone_number=None,
 	):
 		user, variable = None, None
-		if username != None:
-			user = auth.get_user(username)
-			variable = str(username)
+		if uid != None:
+			user = auth.get_user(uid)
+			variable = str(uid)
 		elif email != None:
 			user = auth.get_user_by_email(email)
 			variable = str(email)
@@ -39,13 +39,13 @@ class Users(object):
 			user = auth.get_user_by_phone_number(phone_number)
 			variable = str(phone_number)
 		else:
-			return r3sponse.error_response("Invalid usage, define one of the following parameters: [username, email, phone_number].")
+			return r3sponse.error_response("Invalid usage, define one of the following parameters: [uid, email, phone_number].")
 
 		# check success.
 		if user == None: 
 			return r3sponse.error_response(f"Failed to retrieve user [{variable}].")
 		else:
-			return r3sponse.error_response(f"Successfully retrieved user [{variable}].", {"user":user})
+			return r3sponse.success_response(f"Successfully retrieved user [{variable}].", {"user":user})
 
 
 		#
@@ -100,7 +100,7 @@ class Users(object):
 				"uid":user.uid,
 			})
 		else:
-			return r3sponse.error_response(f"Failed to create user [{email}], error: {error}.")
+			return r3sponse.error_response(f"Failed to create user [{email}], error: {error}")
 
 		#
 	def update(self,
@@ -151,9 +151,9 @@ class Users(object):
 
 		# handle success.
 		if success:
-			return r3sponse.success_response(f"Successfully updated user [{username}].")
+			return r3sponse.success_response(f"Successfully updated user [{uid}].")
 		else:
-			return r3sponse.error_response(f"Failed to update user [{username}], error: {error}.")
+			return r3sponse.error_response(f"Failed to update user [{uid}], error: {error}")
 
 		#
 	def delete(self, 
@@ -169,7 +169,7 @@ class Users(object):
 		if success:
 			return r3sponse.success_response(f"Successfully deleted user [{uid}].")
 		else:
-			return r3sponse.error_response(f"Failed to delete user [{uid}], error: {error}.")
+			return r3sponse.error_response(f"Failed to delete user [{uid}], error: {error}")
 	def iterate(self):
 		return auth.list_users().iterate_all()
 	def verify_id_token(self, id_token):
@@ -193,7 +193,7 @@ class Users(object):
 		if success:
 			return r3sponse.success_response("You are signed in.", {"uid":uid})
 		else:
-			return r3sponse.error_response("You are not signed in., error: {error}.")
+			return r3sponse.error_response("You are not signed in., error: {error}")
 
 		#
 
